@@ -243,7 +243,8 @@ class Feature:
         interval: float = None,
         **kwargs
     ):
-        """Visualizes the output of the feature
+        """Visualizes the output of the feature.
+
         Resolves the feature and visualizes the result. If the output is an Image,
         show it using `pyplot.imshow`. If the output is a list, create an `Animation`.
         For notebooks, the animation is played inline using `to_jshtml()`. For scripts,
@@ -334,7 +335,7 @@ class Feature:
         else:
             # Call get on entire list.
             new_list = self.get(image_list, **feature_input)
-        
+
             if not isinstance(new_list, list):
                 new_list = [Image(new_list)]
 
@@ -769,6 +770,8 @@ class LoadImage(Feature):
         Adds dimensions until it is at least ndim
     to_grayscale : bool
         Whether to convert the image to grayscale
+    get_one_random : bool
+        Extracts a single image from a stack. Only used if as_list is true.
 
     Raises
     ------
@@ -786,6 +789,7 @@ class LoadImage(Feature):
         as_list=False,
         ndim=None,
         to_grayscale=False,
+        get_one_random=False,
         **kwargs
     ):
         super().__init__(
@@ -794,10 +798,21 @@ class LoadImage(Feature):
             as_list=as_list,
             ndim=ndim,
             to_grayscale=to_grayscale,
+            get_one_random=get_one_random,
             **kwargs
         )
 
-    def get(self, *ign, path, load_options, ndim, to_grayscale, as_list, **kwargs):
+    def get(
+        self,
+        *ign,
+        path,
+        load_options,
+        ndim,
+        to_grayscale,
+        as_list,
+        get_one_random,
+        **kwargs
+    ):
         if load_options is None:
             load_options = {}
         try:
@@ -836,8 +851,11 @@ class LoadImage(Feature):
         if ndim and image.ndim < ndim:
             image = np.expand_dims(image, axis=-1)
 
-        if as_list:
-            image = list(image)
+        elif as_list:
+            if get_one_random:
+                image = image[np.random.randint(len(image))]
+            else:
+                image = list(image)
 
         return image
 
